@@ -61,12 +61,13 @@ class ErrorInfo(Error):
 
     name = "no-len-compare"
     code = 115
-    categories = ["iterable", "truthy"]
+    categories = ("iterable", "truthy")
 
 
 CONTAINER_TYPES = {
     "builtins.list",
     "builtins.tuple",
+    "tuple[",
     "builtins.dict",
     "builtins.set",
     "builtins.frozenset",
